@@ -1,8 +1,24 @@
+"""Define the triangular scheme used by triangular elements
+"""
+
+
 import numpy as np
 
 
 class TriangularScheme():
-    def __init__(self, n):
+    """Generate a triangular integration scheme
+
+    Args:
+        n (int): Number of gauss points
+    """
+
+    def __init__(self, n: int) -> None:
+        """Generate a triangular integration scheme
+
+        Args:
+            n (int): Number of gauss points
+        """
+
         # self.Z,self.W = np.polynomial.legendre.leggauss(n)
         # w = np.outer((1 + points) * weights, weights) / 4
         # x = np.outer(1 - points, np.ones(n)) / 2
@@ -10,6 +26,13 @@ class TriangularScheme():
         # points = np.array([x.flatten(), y.flatten()])
         # weights = w.flatten()
         # points = np.array([points[0], points[1], 1 - points[0] - points[1]])
+
+        self.Tj = [
+            lambda s: np.array([(0.5*s+0.5), (s-s)]),
+            lambda s: np.array([1-(0.5*s+0.5), (0.5*s+0.5)]),
+            lambda s: np.array([(s-s), 1-(0.5*s+0.5)]),
+        ]
+
         A0 = 1/3
         A1 = 0.059715871789770
         A2 = 0.797426985353087
