@@ -1,3 +1,7 @@
+"""Elements structures
+"""
+
+
 from .Element import *
 from .E1D import *
 from .E2D import *
