@@ -3,7 +3,7 @@
 
 
 import numpy as np
-from ..Utils import isBetween, roundCorner, giveCoordsCircle
+from ..Utils import isBetween, roundCorner, giveCoordsCircle, angleBetweenAngles
 import matplotlib.pyplot as plt
 from ..Elements.E1D.LinealElement import LinealElement
 from ..Elements.E1D.QuadraticElement import QuadraticElement
@@ -224,18 +224,19 @@ class Geometry:
             self.elements.append(element)
         print('Done!')
 
-    def show(self, texto: int = 10, bolita: int = 0, figsize: list = [17, 10], draw_segs=True, draw_labels=False) -> None:
+    def show(self, texto: int = 10, bolita: int = 0, draw_segs: bool = True, draw_labels: bool = False, draw_bc: bool = False, label_bc: bool = False) -> None:
         """Create a geometry graph
 
         Args:
             texto (int, optional): Text size. Defaults to 10.
             bolita (int, optional): Node size. Defaults to 0.
-            figsize (list, optional): Size of figure. Defaults to [17, 10].
             draw_segs (bool, optional): To draw or not draw the segments. Defaults to True.
             draw_labels (bool, optional): To draw or not draw element labels. Defaults to False.
+            draw_bc (bool, optional): To draw border conditions. Defaults to False.
+            label_bc (bool, optional): To draw labels on border conditions. Defaults to False.
         """
 
-        fig = plt.figure(figsize=figsize)
+        fig = plt.figure()
         ax = fig.add_subplot()
 
         ax.axes.set_aspect('equal')
@@ -245,7 +246,7 @@ class Geometry:
             coords = np.array(coords.tolist() + [coords[0].tolist()])
             X = coords[:, 0]
             Y = coords[:, 1]
-            ax.plot(X, Y, '-', color='black', zorder=-10)
+            ax.plot(X, Y, '-', color='black', alpha=1-0.9*draw_bc, zorder=-10)
             cx = self.centroids[i][0]
             cy = self.centroids[i][1]
             if draw_labels:
@@ -267,13 +268,14 @@ class Geometry:
                         edgecolor='b',
                         linewidth=3,
                         zorder=0,
+                        alpha=1-0.9*draw_bc
                     )
                     cx = (x0+x1)*0.5
                     cy = (y0+y1)*0.5
                     ax.plot(cx, cy, 'o', markersize=texto +
-                            bolita, color='pink')
+                            bolita, color='pink', alpha=1-0.9*draw_bc)
                     ax.annotate(format(i), [
-                                cx, cy], size=texto, textcoords="offset points", xytext=(-0, -2.5), ha='center')
+                                cx, cy], alpha=1-0.9*draw_bc, size=texto, textcoords="offset points", xytext=(-0, -2.5), ha='center')
         except:
             pass
         ax.set_xlabel('x')
@@ -290,6 +292,34 @@ class Geometry:
             for p, l in zip(gdls, labels):
                 ax.annotate(l, p, size=texto, textcoords="offset points",
                             xytext=(-0, -2.5), ha='center')
+        maxx = np.max(gdls[:, 0])
+        maxy = np.max(gdls[:, 1])
+
+        minx = np.min(gdls[:, 0])
+        miny = np.min(gdls[:, 1])
+        coordmax = min(maxx-minx, maxy-miny)
+        tFlecha = coordmax/80
+        if draw_bc:
+            for i, cb in enumerate(self.cbe):
+                coords_cb = gdls[int(cb[0]//self.nvn)]
+                if cb[0] % self.nvn == 0:
+                    color = 'red'
+                    ax.annotate(f"{i}: {cb[1]}"*label_bc, xy=coords_cb, xytext=(
+                        coords_cb[0]-tFlecha, coords_cb[1]), horizontalalignment='center', verticalalignment='center', arrowprops=dict(arrowstyle="->", facecolor=color))
+                elif cb[0] % self.nvn == 1:
+                    color = 'blue'
+                    ax.annotate(f"{i}: {cb[1]}"*label_bc, xy=coords_cb, xytext=(
+                        coords_cb[0], coords_cb[1]+tFlecha), horizontalalignment='center', verticalalignment='center', arrowprops=dict(arrowstyle="->", facecolor=color))
+                elif cb[0] % self.nvn == 2:
+                    color = 'yellow'
+                    ax.annotate(f"{i}: {cb[1]}"*label_bc, xy=coords_cb, xytext=(
+                        coords_cb[0]-tFlecha, coords_cb[1]-tFlecha), horizontalalignment='center', verticalalignment='center', arrowprops=dict(arrowstyle="->", facecolor=color))
+                else:
+                    color = 'black'
+                    ax.annotate(f"{i}: {cb[1]}"*label_bc, xy=coords_cb, xytext=(
+                        coords_cb[0]-tFlecha, coords_cb[1]), horizontalalignment='center', verticalalignment='center', arrowprops=dict(arrowstyle="->", facecolor=color))
+        figManager = plt.get_current_fig_manager()
+        figManager.full_screen_toggle()
 
     def saveMesh(self, ProjectName: str) -> None:
         """Saves the geometry to a MSH file with specified name
@@ -349,6 +379,18 @@ class Geometry:
             self.areas.append(np.abs(area/2))
             self.centroids.append([cx/3/area, cy/3/area])
 
+    def setCbe(self, cbe: list) -> None:
+        """This method have to be used to assign essential boundary conditions. Thes method prevents to assign duplicated border conditions
+
+        Args:
+            cbe (list): Border conditions to be applied
+        """
+        res = []
+        for i in cbe:
+            if i not in res:
+                res.append(i)
+        self.cbe = res
+
     def generateSegmentsFromCoords(self, p0: list, p1: list) -> None:
         """Generates a geometry segment by specified coordinates
 
@@ -464,6 +506,67 @@ class Geometry:
                 else:
                     e.borders[i].dir = 0.0
 
+    def loadOnHole(self, hole: int, sa: float = 0, ea: float = 2*np.pi, fx: Callable = None, fy: Callable = None, tol: float = 1*10**(-5)) -> None:
+        """Assign loads over a hole.
+
+        Args:
+            hole (int): Hole index in wich load will be applied
+            sa (float, optional): Start face angle. Defaults to 0.
+            ea (float, optional): Finish face angle. Defaults to :math:`2\\pi`.
+            fx (Callable, optional): Load Function x component. Defaults to None.
+            fy (Callable, optional): Load Function y component. Defaults to None.
+            tol (float, optional): Tolerancy for finding nodes. Defaults to 1*10**(-5).
+        """
+        holee = self.holes[hole]
+        segments_apply = []
+        for i, segmento in enumerate(holee['segments']):
+            seg_coords = np.array(self.gdls)[segmento]
+            centradas = seg_coords[1]-seg_coords[0]
+            angle = np.arctan2(centradas[1], centradas[0])
+            angle += np.pi/2
+            if angle < 0:
+                angle += 2*np.pi
+            if angleBetweenAngles(sa, ea, angle):
+                segments_apply.append(segmento)
+        for segmento in segments_apply:
+            for i, seg in enumerate(self.segments):
+                if seg == segmento:
+                    self.loadOnSegment(i, fx, fy, tol)
+                    break
+
+    def cbOnHole(self, hole: int, value: float, nv: int = 1, sa: float = 0, ea: float = 2*np.pi, tol: float = 1*10**(-5)) -> list:
+        """Generate a list of border conditions from specified hole.
+
+        Args:
+            hole (int): Hole index in wich load will be applied
+            value (float): Value of the bc
+            nv (int, optional): Variable number, starts with 1. Defaults to 1.
+            sa (float, optional): Start face angle. Defaults to 0.
+            ea (float, optional): Finish face angle. Defaults to :math:`2\\pi`.
+            tol (float, optional): Tolerancy for finding nodes. Defaults to 1*10**(-5).
+
+        Returns:
+            list: List of border conditions that can be concatenated or assigned to the geometry
+        """
+        holee = self.holes[hole]
+        segments_apply = []
+        bc = []
+        for i, segmento in enumerate(holee['segments']):
+            seg_coords = np.array(self.gdls)[segmento]
+            centradas = seg_coords[1]-seg_coords[0]
+            angle = np.arctan2(centradas[1], centradas[0])
+            angle += np.pi/2
+            if angle < 0:
+                angle += 2*np.pi
+            if angleBetweenAngles(sa, ea, angle):
+                segments_apply.append(segmento)
+        for segmento in segments_apply:
+            for i, seg in enumerate(self.segments):
+                if seg == segmento:
+                    bc += self.cbFromSegment(i, value, nv, tol)
+                    break
+        return bc
+
     def cbFromSegment(self, segment: int, value: float, nv: int = 1, tol: float = 1*10**(-5)) -> list:
         """Generate a list of border conditions from specified border.
 
